<?php
/*
Plugin Name: Super Custom Login
Plugin URI: http://middleearmedia.com/labs/plugins/super-custom-login/
Description: This plugin enables users to personalize their WordPress login screen by replacing the default WordPress logo with their own custom logo.
Version: 1.0
Author: Obadiah Metivier
Author URI: http://middleearmedia.com/
License: GPLv2 or later
*/

// If this file is called directly, abort. 
if ( ! defined( 'WPINC' ) ) {
     die;
}

// Add a link to the settings page in the plugin list
function super_custom_login_settings_link($links) {
  $settings_link = '<a href="options-general.php?page=super-custom-login">Settings</a>';
  array_unshift($links, $settings_link);
  return $links;
}
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'super_custom_login_settings_link');

// Add the settings page to the settings menu
function super_custom_login_settings_menu() {
  add_options_page('Super Custom Login', 'Super Custom Login', 'manage_options', 'super-custom-login', 'super_custom_login_settings_page');
}
add_action('admin_menu', 'super_custom_login_settings_menu');

// Define the settings page
function super_custom_login_settings_page() {
  ?>
  <div class="wrap">
    <h1>Super Custom Login Settings</h1>
    <form method="post" action="options.php">
      <?php settings_fields('super_custom_login_settings'); ?>
      <?php do_settings_sections('super_custom_login_settings'); ?>
      <table class="form-table">
        <tr valign="top">
          <th scope="row">Logo URL</th>
          <td><input type="url" name="super_custom_login_logo_url" value="<?php echo esc_attr(get_option('super_custom_login_logo_url')); ?>" /> Enter the URL of your Logo.</td>
        </tr>
        <tr valign="top">
          <th scope="row">Logo Width</th>
          <td><input type="number" name="super_custom_login_logo_width" value="<?php echo esc_attr(get_option('super_custom_login_logo_width', 328)); ?>" /> Enter the width of your Logo, if different from default of 328px.</td>
		</tr>
        <tr valign="top">
          <th scope="row">Logo Height</th>
          <td><input type="number" name="super_custom_login_logo_height" value="<?php echo esc_attr(get_option('super_custom_login_logo_height', 84)); ?>" /> Enter the height of your Logo, if different from default of 84px.</td>
        </tr>
      </table>
      <?php submit_button(); ?>
    </form>
  </div>
  <?php
}

// Register the settings
function super_custom_login_register_settings() {
  register_setting('super_custom_login_settings', 'super_custom_login_logo_url', 'sanitize_text_field');
  register_setting('super_custom_login_settings', 'super_custom_login_logo_width', 'absint');
  register_setting('super_custom_login_settings', 'super_custom_login_logo_height', 'absint');
}
add_action('admin_init', 'super_custom_login_register_settings');

// Replace the login logo with the custom logo
function super_custom_login_logo() {
  $logo_url = get_option('super_custom_login_logo_url');
  $logo_width = get_option('super_custom_login_logo_width', 328);
  $logo_height = get_option('super_custom_login_logo_height', 84);
  if ($logo_url) {
    echo '<style type="text/css">
      #login h1 a {
        background-image: url(' . $logo_url . ');
        background-size: contain;
        width: ' . $logo_width . 'px;
        height: ' . $logo_height . 'px;
		max-width: 100% !important;
      }
	  #login {
	    width: ' . $logo_width . 'px !important;
		max-width: 100% !important;
	  }
	  .login form {
	    width: 280px !important;
		margin-left: auto !important;
		margin-right: auto;
	  }
	  .login #nav {
		text-align: center;
	  }
	  #backtoblog {
		text-align: center;
	  }
    </style>';
  }
}
add_action('login_enqueue_scripts', 'super_custom_login_logo');

// Change the URL that the logo links to
function custom_login_logo_url() {
  return home_url();
}
add_filter('login_headerurl', 'custom_login_logo_url');

// Change the title attribute for the logo link
function custom_login_logo_url_title() {
  return get_bloginfo('name');
}
add_filter('login_headertitle', 'custom_login_logo_url_title');

// Filter the login error messages to return a null value.
add_filter('login_errors', '__return_null');
